<?php

/**
 * Include and setup custom metaboxes and fields. (make sure you copy this file to outside the CMB2 directory)
 *
 * Be sure to replace all instances of 'yourprefix_' with your project's prefix.
 * http://nacin.com/2010/05/11/in-wordpress-prefix-everything/
 *
 * @category YourThemeOrPlugin
 * @package  Demo_CMB2
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/WebDevStudios/CMB2
 */

 /**
 * Only return default value if we don't have a post ID (in the 'post' query variable)
 *
 * @param  bool  $default On/Off (true/false)
 * @return mixed          Returns true or '', the blank default
 */
function knirpse_set_checkbox_default_for_new_post( $default ) {
	return isset( $_GET['post'] ) ? '' : ( $default ? (string) $default : '' );
}

add_action( 'cmb2_admin_init', 'knirpse_register_metabox' );

/**
 * Hook in and add a demo metabox. Can only happen on the 'cmb2_admin_init' or 'cmb2_init' hook.
 */

function knirpse_register_metabox() {

	$prefix = '_knirpse_';

	$prefixpage = '_knirpsepage_';
	
	
	$knirpse_post_meta = new_cmb2_box( array(
		'id'            => $prefixpage . 'blog_post_control',
		'title'         => esc_html__( 'Post Thumb Controller', 'knirpse' ),
		'object_types'  => array( 'post' ), // Post type
		'closed'        => true
	) );
	$knirpse_post_meta->add_field( array(
		'name' => esc_html__( 'Post Format Video', 'knirpse' ),
		'desc' => esc_html__( 'Use This Field When Post Format Video', 'knirpse' ),
		'id'   => $prefix . 'post_format_video',
        'type' => 'text_url',
    ) );
	$knirpse_post_meta->add_field( array(
		'name' => esc_html__( 'Post Format Audio', 'knirpse' ),
		'desc' => esc_html__( 'Use This Field When Post Format Audio', 'knirpse' ),
		'id'   => $prefix . 'post_format_audio',
        'type' => 'oembed',
    ) );
	$knirpse_post_meta->add_field( array(
		'name' => esc_html__( 'Post Thumbnail For Slider', 'knirpse' ),
		'desc' => esc_html__( 'Use This Field When You Want A Slider In Post Thumbnail', 'knirpse' ),
		'id'   => $prefix . 'post_format_slider',
        'type' => 'file_list',
    ) );
	
	$knirpse_page_meta = new_cmb2_box( array(
		'id'            => $prefixpage . 'page_meta_section',
		'title'         => esc_html__( 'Page Meta', 'knirpse' ),
		'object_types'  => array( 'page', 'knirpse_event' ), // Post type
        'closed'        => true
    ) );

    $knirpse_page_meta->add_field( array(
		'name' => esc_html__( 'Page Breadcrumb Area', 'knirpse' ),
		'desc' => esc_html__( 'check to display page breadcrumb area.', 'knirpse' ),
		'id'   => $prefix . 'page_breadcrumb_area',
        'type' => 'select',
        'default' => '1',
        'options'   => array(
            '1'   => esc_html__('Show','knirpse'),
            '2'     => esc_html__('Hide','knirpse'),
        )
    ) );


    $knirpse_page_meta->add_field( array(
		'name' => esc_html__( 'Page Breadcrumb Settings', 'knirpse' ),
		'id'   => $prefix . 'page_breadcrumb_settings',
        'type' => 'select',
        'default'   => 'global',
        'options'   => array(
            'global'   => esc_html__('Global Settings','knirpse'),
            'page'     => esc_html__('Page Settings','knirpse'),
        )
	) );

    $knirpse_page_meta->add_field( array(
        'name'    => esc_html__( 'Breadcumb Image', 'knirpse' ),
        'desc'    => esc_html__( 'Upload an image or enter an URL.', 'knirpse' ),
        'id'      => $prefix . 'breadcumb_image',
        'type'    => 'file',
        // Optional:
        'options' => array(
            'url' => false, // Hide the text input for the url
        ),
        'text'    => array(
            'add_upload_file_text' => __( 'Add File', 'knirpse' ) // Change upload button text. Default: "Add or Upload File"
        ),
        'preview_size' => 'large', // Image size to use when previewing in the admin.
    ) );

    $knirpse_page_meta->add_field( array(
		'name' => esc_html__( 'Page Title', 'knirpse' ),
		'desc' => esc_html__( 'check to display Page Title.', 'knirpse' ),
		'id'   => $prefix . 'page_title',
        'type' => 'select',
        'default' => '1',
        'options'   => array(
            '1'   => esc_html__('Show','knirpse'),
            '2'     => esc_html__('Hide','knirpse'),
        )
	) );

    $knirpse_page_meta->add_field( array(
		'name' => esc_html__( 'Page Title Settings', 'knirpse' ),
		'id'   => $prefix . 'page_title_settings',
        'type' => 'select',
        'options'   => array(
            'default'  => esc_html__('Default Title','knirpse'),
            'custom'  => esc_html__('Custom Title','knirpse'),
        ),
        'default'   => 'default'
    ) );

    $knirpse_page_meta->add_field( array(
		'name' => esc_html__( 'Custom Page Title', 'knirpse' ),
		'id'   => $prefix . 'custom_page_title',
        'type' => 'text'
    ) );

    $knirpse_page_meta->add_field( array(
		'name' => esc_html__( 'Breadcrumb', 'knirpse' ),
		'desc' => esc_html__( 'Select Show to display breadcrumb area', 'knirpse' ),
		'id'   => $prefix . 'page_breadcrumb_trigger',
        'type' => 'switch_btn',
        'default' => knirpse_set_checkbox_default_for_new_post( true ),
    ) );

    $knirpse_layout_meta = new_cmb2_box( array(
		'id'            => $prefixpage . 'page_layout_section',
		'title'         => esc_html__( 'Page Layout', 'knirpse' ),
        'context' 		=> 'side',
        'priority' 		=> 'high',
        'object_types'  => array( 'page' ), // Post type
        'closed'        => true
	) );

	$knirpse_layout_meta->add_field( array(
		'desc'       => esc_html__( 'Set page layout container,container fluid,fullwidth or both. It\'s work only in template builder page.', 'knirpse' ),
		'id'         => $prefix . 'custom_page_layout',
		'type'       => 'radio',
        'options' => array(
            '1' => esc_html__( 'Container', 'knirpse' ),
            '2' => esc_html__( 'Container Fluid', 'knirpse' ),
            '3' => esc_html__( 'Fullwidth', 'knirpse' ),
        ),
	) );

}

add_action( 'cmb2_admin_init', 'knirpse_register_taxonomy_metabox' );
/**
 * Hook in and add a metabox to add fields to taxonomy terms
 */
function knirpse_register_taxonomy_metabox() {

    $prefix = '_knirpse_';
	/**
	 * Metabox to add fields to categories and tags
	 */
	$knirpse_term_meta = new_cmb2_box( array(
		'id'               => $prefix.'term_edit',
		'title'            => esc_html__( 'Category Metabox', 'knirpse' ),
		'object_types'     => array( 'term' ),
		'taxonomies'       => array( 'category'),
	) );
	$knirpse_term_meta->add_field( array(
		'name'     => esc_html__( 'Extra Info', 'knirpse' ),
		'id'       => $prefix.'term_extra_info',
		'type'     => 'title',
		'on_front' => false,
	) );
	$knirpse_term_meta->add_field( array(
		'name' => esc_html__( 'Category Image', 'knirpse' ),
		'desc' => esc_html__( 'Set Category Image', 'knirpse' ),
		'id'   => $prefix.'term_avatar',
        'type' => 'file',
        'text'    => array(
			'add_upload_file_text' => esc_html__('Add Image','knirpse') // Change upload button text. Default: "Add or Upload File"
		),
	) );


	/**
	 * Metabox for the user profile screen
	 */
	$knirpse_user = new_cmb2_box( array(
		'id'               => $prefix.'user_edit',
		'title'            => esc_html__( 'User Profile Metabox', 'knirpse' ), // Doesn't output for user boxes
		'object_types'     => array( 'user' ), // Tells CMB2 to use user_meta vs post_meta
		'show_names'       => true,
		'new_user_section' => 'add-new-user', // where form will show on new user page. 'add-existing-user' is only other valid option.
	) );
	$knirpse_user->add_field( array(
		'name'     => esc_html__( 'Social Profile', 'knirpse' ),
		'id'       => $prefix.'user_extra_info',
		'type'     => 'title',
		'on_front' => false,
	) );

	$group_field_id = $knirpse_user->add_field( array(
        'id'          => $prefix .'social_profile_group',
        'type'        => 'group',
        'description' => __( 'Social Profile', 'knirpse' ),
        'options'     => array(
            'group_title'       => __( 'Social Profile {#}', 'knirpse' ), // since version 1.1.4, {#} gets replaced by row number
            'add_button'        => __( 'Add Another Social Profile', 'knirpse' ),
            'remove_button'     => __( 'Remove Social Profile', 'knirpse' ),
            'closed'         => true
        ),
    ) );

    $knirpse_user->add_group_field( $group_field_id, array(
        'name'        => __( 'Icon Class', 'knirpse' ),
        'id'          => $prefix .'social_profile_icon',
        'type'        => 'text', // This field type
    ) );

    $knirpse_user->add_group_field( $group_field_id, array(
        'desc'       => esc_html__( 'Set social profile link.', 'knirpse' ),
        'id'         => $prefix . 'lawyer_social_profile_link',
        'name'       => esc_html__( 'Social Profile link', 'knirpse' ),
        'type'       => 'text'
    ) );
}

add_action( 'cmb2_admin_init', 'knirpse_event_metabox' );
/**
 * Hook in and add a metabox to event post
 */
function knirpse_event_metabox() {

    $prefix = '_knirpse_';

    /**
     * Metabox for the Serivice Post Type
     */
    $knirpse_events = new_cmb2_box( array(
        'id'               => $prefix.'event_post',
        'title'            => esc_html__( 'Event :: Additional Informations', 'knirpse' ), // Doesn't output for user boxes
        'object_types'     => array( 'kundax_event' ), // Tells CMB2 to use user_meta vs post_meta
        'show_names'       => true,
    ) );

    $knirpse_events->add_field( array(
        'name'     => esc_html__( 'Event Start Day', 'knirpse' ),
        'id'       => $prefix.'event_start',
        'type' => 'text_date',
        'date_format' => 'j \ M ',
    ) );
    
    $knirpse_events->add_field( array(
        'name'     => esc_html__( 'Event Time Schedule', 'knirpse' ),
        'id'       => $prefix.'event_schedule',
        'type'     => 'textarea_small',
    ) );
    $knirpse_events->add_field( array(
        'name'     => esc_html__( 'Event Location', 'knirpse' ),
        'id'       => $prefix.'event_laction',
        'type'     => 'textarea_small',
    ) );
}
