<?php

/**
 * @Packge     : Knirpse
 * @Version    : 1.0
 * @Author     : Vecurosoft
 * @Author URI : https://www.vecurosoft.com/
 *
 */


// Block direct access
if( ! defined( 'ABSPATH' ) ){
    exit;
}

 // theme option callback
function knirpse_opt( $id = null, $url = null ){
    global $knirpse_opt;

    if( $id && $url ){

        if( isset( $knirpse_opt[$id][$url] ) && $knirpse_opt[$id][$url] ){
            return $knirpse_opt[$id][$url];
        }
    }else{
        if( isset( $knirpse_opt[$id] )  && $knirpse_opt[$id] ){
            return $knirpse_opt[$id];
        }
    }
}


// theme logo
function knirpse_theme_logo() {
    // escaping allow html
    $allowhtml = array(
        'a'    => array(
            'href' => array()
        ),
        'span' => array(),
        'i'    => array(
            'class' => array()
        )
    );
    $siteUrl = home_url('/');
    if( has_custom_logo() ) {
        $custom_logo_id = get_theme_mod( 'custom_logo' );
        $siteLogo = '';
        $siteLogo .= '<a class="logo" href="'.esc_url( $siteUrl ).'">';
        $siteLogo .= knirpse_img_tag( array(
            "class" => "img-fluid",
            "url"   => esc_url( wp_get_attachment_image_url( $custom_logo_id, 'full') )
        ) );
        $siteLogo .= '</a>';

        return $siteLogo;
    } elseif( !knirpse_opt('knirpse_text_title') && knirpse_opt('knirpse_site_logo', 'url' )  ){

        $siteLogo = '<img class="img-fluid" src="'.esc_url( knirpse_opt('knirpse_site_logo', 'url' ) ).'" alt="'.esc_attr__( 'logo', 'knirpse' ).'" />';
        return '<a class="logo" href="'.esc_url( $siteUrl ).'">'.$siteLogo.'</a>';


    }elseif( knirpse_opt('knirpse_text_title') ){
        return '<h2 class="mb-0"><a class="logo" href="'.esc_url( $siteUrl ).'">'.wp_kses( knirpse_opt('knirpse_text_title'), $allowhtml ).'</a></h2>';
    }else{
        return '<h2 class="mb-0"><a class="logo" href="'.esc_url( $siteUrl ).'">'.esc_html( get_bloginfo('name') ).'</a></h2>';
    }
}

// custom meta id callback
function knirpse_meta( $id = '' ){
    $value = get_post_meta( get_the_ID(), '_knirpse_'.$id, true );
    return $value;
}


// Blog Date Permalink
function knirpse_blog_date_permalink() {
    $year  = get_the_time('Y');
    $month_link = get_the_time('m');
    $day   = get_the_time('d');
    $link = get_day_link( $year, $month_link, $day);
    return $link;
}

//audio format iframe match
function knirpse_iframe_match() {
    $audio_content = knirpse_embedded_media( array('audio', 'iframe') );
    $iframe_match = preg_match("/\iframe\b/i",$audio_content, $match);
    return $iframe_match;
}


//Post embedded media
function knirpse_embedded_media( $type = array() ){
    $content = do_shortcode( apply_filters( 'the_content', get_the_content() ) );
    $embed   = get_media_embedded_in_content( $content, $type );


    if( in_array( 'audio' , $type) ){
        if( count( $embed ) > 0 ){
            $output = str_replace( '?visual=true', '?visual=false', $embed[0] );
        }else{
           $output = '';
        }

    }else{
        if( count( $embed ) > 0 ){
            $output = $embed[0];
        }else{
           $output = '';
        }
    }
    return $output;
}


// WP post link pages
function knirpse_link_pages(){
    wp_link_pages( array(
        'before'      => '<div class="page-links"><span class="page-links-title">' . esc_html__( 'Pages:', 'knirpse' ) . '</span>',
        'after'       => '</div>',
        'link_before' => '<span>',
        'link_after'  => '</span>',
        'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'knirpse' ) . ' </span>%',
        'separator'   => '<span class="screen-reader-text">, </span>',
    ) );
}


// Data Background image attr
function knirpse_data_bg_attr( $imgUrl = '' ){
    return 'data-bg-img="'.esc_url( $imgUrl ).'"';
}

// image alt tag
function knirpse_image_alt( $url = '' ){
    if( $url != '' ){
        // attachment id by url
        $attachmentid = attachment_url_to_postid( esc_url( $url ) );
       // attachment alt tag
        $image_alt = get_post_meta( esc_html( $attachmentid ) , '_wp_attachment_image_alt', true );
        if( $image_alt ){
            return $image_alt ;
        }else{
            $filename = pathinfo( esc_url( $url ) );
            $alt = str_replace( '-', ' ', $filename['filename'] );
            return $alt;
        }
    }else{
       return;
    }
}


// Flat Content wysiwyg output with meta key and post id

function knirpse_get_textareahtml_output( $content ) {
    global $wp_embed;

    $content = $wp_embed->autoembed( $content );
    $content = $wp_embed->run_shortcode( $content );
    $content = wpautop( $content );
    $content = do_shortcode( $content );

    return $content;
}

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */

function knirpse_pingback_header() {
    if ( is_singular() && pings_open() ) {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'knirpse_pingback_header' );


// Excerpt More
function knirpse_excerpt_more( $more ) {
    return '...';
}

add_filter( 'excerpt_more', 'knirpse_excerpt_more' );


// knirpse comment template callback
function knirpse_comment_callback( $comment, $args, $depth ) {
        $add_below = 'comment';
    ?>
    <li <?php comment_class( array('vs-comment') ); ?>>
        <div id="comment-<?php comment_ID() ?>" class="vs-post-comment">
            <?php
                if( get_avatar( $comment, 100 )  ) :
            ?>
            <!-- Author Image -->
            <div class="comment-avater">
                <?php
                    if ( $args['avatar_size'] != 0 ) {
                        echo get_avatar( $comment, 100 );
                    }
                ?>
            </div>
            <!-- Author Image -->
            <?php
                endif;
            ?>
            <!-- Comment Content -->
            <div class="comment-content">
                <span class="commented-on"> <?php printf( esc_html__('%1$s', 'knirpse'), get_comment_date() ); ?> </span>
                <h4 class="name"><?php echo esc_html( ucwords( get_comment_author() ) ); ?></h4>
                <p class="text"><?php comment_text(); ?></p>
                <div class="reply_and_edit">
                    <?php
                        $reply_text = esc_html__( 'Reply', 'knirpse' );
                        $edit_reply_text = esc_html__( 'Edit', 'knirpse' );
                        comment_reply_link(array_merge( $args, array( 'add_below' => $add_below, 'depth' => 3, 'max_depth' => 5, 'reply_text' => $reply_text ) ) );
                        edit_comment_link( $edit_reply_text, '  ', '' );
                    ?>
                </div>
                <?php if ( $comment->comment_approved == '0' ) : ?>
                <p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'knirpse' ); ?></p>
                <?php endif; ?>
            </div>
        </div>
        <!-- Comment Content -->
<?php
}

//body class
add_filter( 'body_class', 'knirpse_body_class' );
function knirpse_body_class( $classes ) {
    if( class_exists('ReduxFramework') ) {
        $knirpse_blog_single_sidebar = knirpse_opt('knirpse_blog_single_sidebar');
        if( ($knirpse_blog_single_sidebar != '2' && $knirpse_blog_single_sidebar != '3' ) || ! is_active_sidebar('knirpse-blog-sidebar') ) {
            $classes[] = 'no-sidebar';
        }
    } else {
        if( !is_active_sidebar('knirpse-blog-sidebar') ) {
            $classes[] = 'no-sidebar';
        }
    }
    return $classes;
}


function knirpse_footer_global_option(){

    // Knirpse Widget Enable Disable
    if( class_exists( 'ReduxFramework' ) ){
        $knirpse_footer_widget_enable = knirpse_opt( 'knirpse_footerwidget_enable' );
    }else{
        $knirpse_footer_widget_enable = '';
    }
    // Knirpse Footer Bottom Enable Disable
    if( class_exists( 'ReduxFramework' ) ){
        $knirpse_footer_bottom_active = knirpse_opt( 'knirpse_disable_footer_bottom' );
    }else{
        $knirpse_footer_bottom_active = '1';
    }
    // Knirpse Animation Image for footer
    $animation_first_image   = knirpse_opt( 'knirpse_first_animation', 'url' );
    $animation_second_image  = knirpse_opt( 'knirpse_second_animation', 'url' );
    $animation_third_image   = knirpse_opt( 'knirpse_third_animation', 'url' );
    $animation_fourth_image  = knirpse_opt( 'knirpse_fourth_animation', 'url' );
    $animation_fifth_image   = knirpse_opt( 'knirpse_fifth_animation', 'url' );
    $animation_sixth_image   = knirpse_opt( 'knirpse_sixth_animation', 'url' );

    $allowhtml = array(
        'p'         => array(
            'class'     => array()
        ),
        'span'      => array(
            'class'     => array(),
        ),
        'a'         => array(
            'href'      => array(),
            'title'     => array(),
            'class'     => array(),
        ),
        'br'        => array(),
        'em'        => array(),
        'strong'    => array(),
        'b'         => array(),
    );
    if( $knirpse_footer_widget_enable == '1' || $knirpse_footer_bottom_active == '1' ){


        echo '<!---footer-wrapper start-->';
        echo '<footer class="footer-wrapper footer-layout3">';
            if( $knirpse_footer_widget_enable == '1' ){
                if( $animation_first_image ){
                    echo '<div class="shape-mockup movingX d-none d-hd-block" data-top="7%" data-left="5%">';
                        echo knirpse_img_tag( array(
                            "url"   => esc_url( $animation_first_image ),
                        ) );
                   echo '</div>';
                }
                if( ! empty( $animation_second_image ) ){
                    echo '<div class="shape-mockup movingX-reverse d-none d-hd-block" data-top="62%" data-left="10%">';
                        echo knirpse_img_tag( array(
                            "url"   => esc_url( $animation_second_image ),
                        ) );
                    echo '</div>';
                }
                if( ! empty( $animation_third_image ) ){
                    echo '<div class="shape-mockup rotate d-none d-hd-block" data-top="69%" data-left="32%">';
                        echo knirpse_img_tag( array(
                            "url"   => esc_url( $animation_third_image ),
                        ) );
                    echo '</div>';
                }
                if( ! empty( $animation_fourth_image ) ){
                    echo '<div class="shape-mockup rotate d-none d-hd-block" data-top="3%" data-left="46%">';
                        echo knirpse_img_tag( array(
                            "url"   => esc_url( $animation_fourth_image ),
                        ) );
                    echo '</div>';
                }
                if( ! empty( $animation_fifth_image ) ){
                    echo '<div class="shape-mockup movingX-reverse d-none d-hd-block" data-top="18%" data-right="3%">';
                        echo knirpse_img_tag( array(
                            "url"   => esc_url( $animation_fifth_image ),
                        ) );
                    echo '</div>';
                }
                if( ! empty( $animation_sixth_image ) ){
                    echo '<div class="shape-mockup movingX d-none d-hd-block" data-top="62%" data-right="6%">';
                        echo knirpse_img_tag( array(
                            "url"   => esc_url( $animation_sixth_image ),
                        ) );
                    echo '</div>';
                }
                if( ( is_active_sidebar( 'knirpse-footer-1' ) || is_active_sidebar( 'knirpse-footer-2' ) || is_active_sidebar( 'knirpse-footer-3' ) || is_active_sidebar( 'knirpse-footer-4' ) ) ) {
                    echo '<div class="widget-area">';
                        echo '<div class="container">';
                            echo '<div class="row justify-content-between">';
                                echo '<!-- About Widget-->';
                                if( is_active_sidebar( 'knirpse-footer-1' )){
                                   dynamic_sidebar( 'knirpse-footer-1' );
                                }
                                if( is_active_sidebar( 'knirpse-footer-2' )){
                                   dynamic_sidebar( 'knirpse-footer-2' );
                                }
                                if( is_active_sidebar( 'knirpse-footer-3' )){
                                   dynamic_sidebar( 'knirpse-footer-3' );
                                }
                                if( is_active_sidebar( 'knirpse-footer-4' )){
                                   dynamic_sidebar( 'knirpse-footer-4' );
                                }
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                }
            }
            if( $knirpse_footer_bottom_active == '1' ){
                echo '<div class="footer-copyright">';
                    echo '<div class="container">';
                        echo '<p class="copyright">'.wp_kses( knirpse_opt( 'knirpse_copyright_text' ), $allowhtml ).'</p>';
                    echo '</div>';
                echo '</div>';
            }
        echo '</footer>';
        echo '<!---footer-wrapper end-->';
    }
}

function knirpse_social_icon(){
    $knirpse_social_icon = knirpse_opt( 'knirpse_social_links' );
    if( ! empty( $knirpse_social_icon ) && isset( $knirpse_social_icon ) ){
        echo '<ul>';
        foreach( $knirpse_social_icon as $social_icon ){
            if( ! empty( $social_icon['title'] ) ){
                echo '<li><a href="'.esc_url( $social_icon['url'] ).'"><i class="'.esc_attr( $social_icon['title'] ).'"></i></a></li> ';
            }
        }
        echo '</ul>';
    }
}

// global header
function knirpse_global_header_option() {

    echo '<div class="vs-header">';
    knirpse_header_topbar();
    if( class_exists( 'ReduxFramework' ) ){
        $knirpse_offcanvas          = knirpse_opt( 'knirpse_offcanvas_switcher' );
        $knirpse_search             = knirpse_opt( 'knirpse_search_switcher' );
    }else{
        $knirpse_offcanvas          = '';
        $knirpse_search             = '';
    }
    if( class_exists( 'ReduxFramework' ) ){

        echo '<!--vs-main-menu-wrapper start-->';
        echo '<div class="sticky-wrapper">';
            echo '<div class="sticky-active">';
                echo '<div class="header-menu-area">';
                    echo '<div class="container position-relative">';
                        echo '<div class="row gx-20 align-items-center justify-content-between">';
                            echo '<div class="col-auto">';
                                echo '<div class="header-logo">';
                                    echo knirpse_theme_logo();
                                echo '</div>';
                            echo '</div>';
                            echo '<div class="col-auto">';
                                if( has_nav_menu( 'primary-menu' ) ) {
                                    echo '<nav class="main-menu menu-style1 d-none d-lg-inline-block">';
                                        wp_nav_menu( array(
                                            "theme_location"    => 'primary-menu',
                                            "container"         => '',
                                            "menu_class"        => ''
                                        ) );
                                    echo '</nav>';
                                }
                                echo '<button type="button" class="vs-menu-toggle d-inline-block d-lg-none"><i class="far fa-bars"></i> '.esc_html__('Menu', 'knirpse').'</button>';
                            echo '</div>';
                            echo '<div class="col-auto d-none d-xl-block">';
                                echo '<div class="header-button">';
                                    if(!empty( knirpse_opt( 'knirpse_btn_text' ) )){
                                        echo '<a href="'.esc_url( knirpse_opt( 'knirpse_btn_url' ) ).'" class="vs-btn wave-btn">'.esc_html( knirpse_opt( 'knirpse_btn_text' ) ).'</a>';
                                    }
                                    if($knirpse_search ){
                                        echo '<button type="button" class="searchBoxToggler icon-btn"><i class="far fa-search"></i></button>';
                                    }
                                    if( is_active_sidebar( 'knirpse-offcanvas' ) && $knirpse_offcanvas == 1 ){
                                        echo '<button type="button" class="sideMenuToggler icon-btn"><i class="fal fa-bars"></i></button>';
                                    }
                                echo '</div>';
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
            echo '</div>';
        echo '</div>';
        echo '<!--vs-main-menu-wrapper end-->';
        echo '<div class="popup-search-box d-none d-lg-block  ">';
            echo '<button class="searchClose border-theme text-theme"><i class="fal fa-times"></i></button>';
            echo '<form role="search" method="get" action="'.esc_url( home_url( '/' ) ).'">';
                echo '<input value="'.esc_html( get_search_query() ).'" name="s" class="border-theme" required type="search" placeholder="'.esc_attr__('What are you looking for?', 'knirpse').'">';
                echo '<button type="submit"><i class="fal fa-search"></i></button>';
            echo '</form>';
        echo '</div>';

        if( is_active_sidebar( 'knirpse-offcanvas' ) ){
            echo '<!-- Side menu start -->';
            echo '<div class="sidemenu-wrapper">';
                echo '<div class="sidemenu-content">';
                    echo '<button class="closeButton sideMenuCls"><i class="far fa-times"></i></button>';
                    if( is_active_sidebar( 'knirpse-offcanvas' ) ) :
                        dynamic_sidebar( 'knirpse-offcanvas' );
                    endif;
                echo '</div>';
            echo '</div>';
            echo '<!-- Side menu end -->';
        }
        echo '<!--vs-mobile-menu start-->';
	    echo '<div class="vs-menu-wrapper">';
	        echo '<div class="vs-menu-area">';
	            echo '<button class="vs-menu-toggle"><i class="fal fa-times"></i></button>';
	            echo '<div class="mobile-logo">';
	                echo knirpse_theme_logo();
	            echo '</div>';
	            if( has_nav_menu( 'primary-menu' ) ){
	                echo '<div class="vs-mobile-menu">';
	                    wp_nav_menu( array(
	                        "theme_location"    => 'primary-menu',
	                        "container"         => '',
	                        "menu_class"        => ''
	                    ) );
	                echo '</div>';
	            }
	        echo '</div>';
	    echo '</div>';
	    echo '<!--vs-mobile-menu end-->';
    }else{
        knirpse_global_header();
    }
    echo '</div>';
}

// knirpse woocommerce breadcrumb
function knirpse_woo_breadcrumb( $args ) {
    return array(
        'delimiter'   => '',
        'wrap_before' => '<ul class="breadcumb-menu">',
        'wrap_after'  => '</ul>',
        'before'      => '<li>',
        'after'       => '</li>',
        'home'        => _x( 'Home', 'breadcrumb', 'knirpse' ),
    );
}

add_filter( 'woocommerce_breadcrumb_defaults', 'knirpse_woo_breadcrumb' );

function knirpse_custom_search_form( $class ) {
    echo '<!-- Search Form -->';

    echo '<form role="search" method="get" action="'.esc_url( home_url( '/' ) ).'" class="'.esc_attr( $class ).'">';
        echo '<label class="searchIcon">';
            echo knirpse_img_tag( array(
                "url"   => esc_url( get_theme_file_uri( '/assets/img/search-2.svg' ) ),
                "class" => "svg"
            ) );
            echo '<input value="'.esc_html( get_search_query() ).'" name="s" required type="search" placeholder="'.esc_attr__('What are you looking for?', 'knirpse').'">';
        echo '</label>';
    echo '</form>';
    echo '<!-- End Search Form -->';
}



//Fire the wp_body_open action.
if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        do_action( 'wp_body_open' );
    }
}

//Remove Tag-Clouds inline style
add_filter( 'wp_generate_tag_cloud', 'knirpse_remove_tagcloud_inline_style',10,1 );
function knirpse_remove_tagcloud_inline_style( $input ){
   return preg_replace('/ style=("|\')(.*?)("|\')/','',$input );
}

function knirpse_setPostViews( $postID ) {
    $count_key  = 'post_views_count';
    $count      = get_post_meta( $postID, $count_key, true );
    if( $count == '' ){
        $count = 0;
        delete_post_meta( $postID, $count_key );
        add_post_meta( $postID, $count_key, '0' );
    }else{
        $count++;
        update_post_meta( $postID, $count_key, $count );
    }
}

function knirpse_getPostViews( $postID ){
    $count_key  = 'post_views_count';
    $count      = get_post_meta( $postID, $count_key, true );
    if( $count == '' ){
        delete_post_meta( $postID, $count_key );
        add_post_meta( $postID, $count_key, '0' );
        return __( '0', 'knirpse' );
    }
    return $count;
}


/* This code filters the Categories archive widget to include the post count inside the link */
add_filter( 'wp_list_categories', 'knirpse_cat_count_span' );
function knirpse_cat_count_span( $links ) {
    $links = str_replace('</a> (', '</a> <span class="category-number">', $links);
    $links = str_replace(')', '</span>', $links);
    return $links;
}

/* This code filters the Archive widget to include the post count inside the link */
add_filter( 'get_archives_link', 'knirpse_archive_count_span' );
function knirpse_archive_count_span( $links ) {
    $links = str_replace('</a>&nbsp;(', '</a> <span class="category-number">', $links);
    $links = str_replace(')', '</span>', $links);
    return $links;
}

// Knirpse Default Header
if( ! function_exists( 'knirpse_global_header' ) ){
    function knirpse_global_header(){
        echo '<div class="popup-search-box d-none d-lg-block  ">';
            echo '<button class="searchClose border-theme text-theme"><i class="fal fa-times"></i></button>';
            echo '<form role="search" method="get" action="'.esc_url( home_url( '/' ) ).'">';
                echo '<input value="'.esc_html( get_search_query() ).'" class="border-theme" name="s" required type="search" placeholder="'.esc_attr__('What are you looking for?', 'knirpse').'">';
                echo '<button type="submit"><i class="fal fa-search"></i></button>';
            echo '</form>';
        echo '</div>';

        echo '<!--======== Header ========-->';
        echo '<div class="vs-header">';
            echo '<!--vs-main-menu-wrapper start-->';
            echo '<div class="sticky-wrapper">';
                echo '<div class="sticky-active">';
                    echo '<div class="header-menu-area">';
                        echo '<div class="container position-relative">';
                            echo '<div class="row gx-20 align-items-center justify-content-between">';
                                echo '<div class="col-auto">';
                                    echo '<div class="header-logo">';
                                        echo knirpse_theme_logo();
                                    echo '</div>';
                                echo '</div>';
                                echo '<div class="col-auto">';
                                    if( has_nav_menu( 'primary-menu' ) ) {
                                        echo '<nav class="main-menu menu-style1 d-none d-lg-inline-block">';
                                            wp_nav_menu( array(
                                                "theme_location"    => 'primary-menu',
                                                "container"         => '',
                                                "menu_class"        => ''
                                            ) );
                                        echo '</nav>';
                                    }
                                    echo '<button type="button" class="vs-menu-toggle d-inline-block d-lg-none"><i class="far fa-bars"></i> '.esc_html__('Menu', 'knirpse').'</button>';
                                echo '</div>';
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
            echo '</div>';
            echo '<!--vs-main-menu-wrapper end-->';
        echo '</div>';
    }
}

if( ! function_exists( 'knirpse_header_topbar' ) ){
    function knirpse_header_topbar(){
        if( class_exists( 'ReduxFramework' ) ){
            $knirpse_show_header_topbar = knirpse_opt( 'knirpse_header_topbar_switcher' );
            $knirpse_show_social_icon   = knirpse_opt( 'knirpse_header_topbar_social_icon_switcher' );
        }else{
            $knirpse_show_header_topbar = '';
            $knirpse_show_social_icon   = '';
        }

        if( $knirpse_show_header_topbar ){
            $allowhtml = array(
                'a'    => array(
                    'href' => array(),
                    'class' => array()
                ),
                'u'    => array(
                    'class' => array()
                ),
                'span' => array(
                    'class' => array()
                ),
                'i'    => array(
                    'class' => array()
                )
            );

            $mobile     = knirpse_opt( 'knirpse_topbar_phone' );

            $replace    = array(' ','-',' - ');
            $with       = array('','','');

            $mobileurl  = str_replace( $replace, $with, $mobile );
            $address    = knirpse_opt( 'knirpse_topbar_address' );
            $address_url    = knirpse_opt( 'knirpse_topbar_address_location' );
            $office_hours    = knirpse_opt( 'knirpse_topbar_office_hours' );

            echo '<!--header-top-wrapper start-->';
            echo '<div class="header-top-area d-none d-lg-block">';
                echo '<div class="container">';
                    echo '<div class="row align-items-center justify-content-between">';
                        echo '<div class="col-auto">';
                            echo '<div class="header-links">';
                                echo '<ul>';
                                    if( ! empty($office_hours ) ){
                                        echo '<li><i class="fal fa-clock"></i>'.esc_html( $office_hours ).'</li>';
                                    }

                                    if( ! empty($mobile ) ){
                                        echo '<li><i class="fal fa-phone-alt"></i><a href="'.esc_attr( 'tel:'.$mobileurl ).'">'.esc_html( $mobile ).'</a></li>';
                                    }
                                    if( ! empty($address ) ){
                                        echo '<li><i class="fal fa-map-marker-alt"></i> <a href="'.esc_url($address_url).'">'.esc_html( $address ).'</a></li>';
                                    }
                                echo '</ul>';
                            echo '</div>';
                        echo '</div>';
                        if( $knirpse_show_social_icon ){
                            echo '<div class="col-auto">';
                                echo '<div class="header-social">';
                                    knirpse_social_icon();
                                echo '</div>';
                            echo '</div>';
                        }
                    echo '</div>';
                echo '</div>';
            echo '</div>';
            echo '<!--header-top-wrapper end-->';
        }
    }
}

// Add Extra Class On Comment Reply Button
function knirpse_custom_comment_reply_link( $content ) {
    $extra_classes = 'reply-btn';
    return preg_replace( '/comment-reply-link/', 'comment-reply-link ' . $extra_classes, $content);
}

add_filter('comment_reply_link', 'knirpse_custom_comment_reply_link', 99);

// Add Extra Class On Edit Comment Link
function knirpse_custom_edit_comment_link( $content ) {
    $extra_classes = 'reply-btn';
    return preg_replace( '/comment-edit-link/', 'comment-edit-link ' . $extra_classes, $content);
}

add_filter('edit_comment_link', 'knirpse_custom_edit_comment_link', 99);


function knirpse_post_classes( $classes, $class, $post_id ) {
    if ( get_post_type() === 'post' ) {
        if( ! is_single() ){
            $classes[] = "vs-blog blog-single wow fadeInUp";
        }else{
            $classes[] = "wow fadeInUp";
        }
    }elseif( get_post_type() === 'product' ){
        // Return Class
    }elseif( get_post_type() === 'page' ){
        $classes[] = "page--item";
    }

    return $classes;
}
add_filter( 'post_class', 'knirpse_post_classes', 10, 3 );